SpectrumWars
============

SpectrumWars is a work-in-progress programming game where players compete for
bandwidth on a limited piece of a radio spectrum.

On-line documentation:

https://spectrumwars.readthedocs.org/en/latest/

Source code repository:

https://github.com/avian2/spectrumwars


Contents
--------

This Python package contains the game controller.

It can be used run the game on a simulated testbed. In that case, no special
hardware or exotic software dependencies are required. This is useful if you
are developing player code to compete in a SpectrumWars game.

It can also be used to run a game on a real wireless testbed, however this
requires a more complicated setup.

More information can be found in documentation linked above.


License
-------

Copyright (C) 2015 SensorLab, Jozef Stefan Institute http://sensorlab.ijs.si

Written by Tomaz Solc, tomaz.solc@ijs.si

This work has been partially funded by the European Community through the
7th Framework Programme project CREW (FP7-ICT-2009-258301).

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/

..
    vim: tw=75 ts=4 sw=4 expandtab softtabstop=4
